from distutils.core import setup

setup(name='Distutils',
      version='0.0.2',
      description='Toolkit Lennart',
      author='Lennart Rooden',
      author_email='lennart.rs@gmail.com',
      url='https://pypi.org/project/toolkit-lennart/0.0.1/',
      packages=['toolkit_lennart'],
     )